Base Transport Interface - kombu.transport.base — Kombu v0.1.0 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »

# Base Transport Interface - kombu.transport.base

Transport base classes.

class `kombu.transport.base.` `Message`(channel, body=None, delivery_tag=None, content_type=None, content_encoding=None, delivery_info={}, properties=None, headers=None, **kwargs)

  Base class for received messages.

  exception `MessageStateError`

    The message has already been acknowledged.

  `Message.` `ack`()

    Acknowledge this message as being processed., This will remove the message from the queue.

    Raises MessageStateError:
    | If the message has already been acknowledged/requeued/rejected.

  `Message.` `acknowledged`
  `Message.` `decode`()

    Deserialize the message body, returning the original python structure sent by the publisher.

  `Message.` `payload`

    The decoded message.

  `Message.` `reject`()

    Reject this message.

    The message will be discarded by the server.

    Raises MessageStateError:
    | If the message has already been acknowledged/requeued/rejected.

  `Message.` `requeue`()

    Reject this message and put it back on the queue.

    You must not use this method as a means of selecting messages to process.

    Raises MessageStateError:
    | If the message has already been acknowledged/requeued/rejected.

class `kombu.transport.base.` `Transport`(client, **kwargs)

  Base class for transports.

  `close_connection`(connection)
  `create_channel`(connection)
  `drain_events`(connection, **kwargs)
  `establish_connection`()

### Navigation

- index
- modules |
- next |
- previous |
- Kombu v0.1.0 documentation »
- API Reference »